import { useLayoutEffect, useState } from "react"
import ResizeObserver from "resize-observer-polyfill"

const zeroBounds = new DOMRect()

export default (cb?: (size: DOMRect) => void) => {
    const [el, setEl] = useState<HTMLElement | null>(null)
    const [bounds, setBounds] = useState(zeroBounds)

    useLayoutEffect(() => {
        if (!el) return
        
        const resizeObserver = new ResizeObserver(() => {
            const bounds = el.getBoundingClientRect()
            cb?.(bounds)
            setBounds(bounds)
        })
        resizeObserver.observe(el)

        return () => {
            resizeObserver.disconnect()
        }
    }, [el])
    
    return <const>[setEl, bounds, el]
}